@@ -567,6 +567,7 @@ esegui_query("update $tableappartamenti set app_vicini = $app_vicini where idapp
 } # fine if ($app_vicini and assegna_vicini_nc != "SI")
 } # fine for $num
 fwrite($fileaperto,"\"; \n?>");
+fclose($fileaperto);
 if ($assegna_vicini_nc == "SI") {
 $appart = esegui_query("select * from $tableappartamenti");
 for ( $num1 = 0; $num1 < $numappartamenti; $num1 = $num1 + 1) {
@@ -589,6 +590,38 @@ esegui_query("update $tableappartamenti set app_vicini = '$app_vicini' where ida
 } # fine for $num1
 } # fine if ($assegna_vicini_nc == "SI")
 
+if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php")) {
+include(C_DATI_PATH."/ini.php");
+$admin = "";
+if (defined('C_ADMIN_NAME')) $admin = C_ADMIN_NAME;
+if (htmlspecialchars($admin) != $admin) $admin = "";
+if (strcmp($admin,"")) {
+esegui_query("update $tableutenti set nome_utente = '".aggslashdb($admin)."' where idutenti = '1'");
+$passw = "";
+if (defined('C_ADMIN_PASS')) $passw = C_ADMIN_PASS;
+if ($passw != str_replace("&","",$passw)) $passw = "";
+if (strcmp($passw,"")) {
+if (C_ADMIN_MD5P >= "1" and C_ADMIN_MD5P <= "15") $md5p = C_ADMIN_MD5P;
+else $md5p = 0;
+if (defined('C_ADMIN_SALT')) $salt = C_ADMIN_SALT;
+else {
+if ($md5p) $salt = "";
+else {
+srand((double) microtime() * 1000000);
+$valori = "=?#@%abcdefghijkmnpqrstuvwxzABCDEFGHJKLMNPQRSTUVWXZ1234567890";
+$salt = substr($valori,rand(0,4),1);
+for ($num1 = 0 ; $num1 < 19 ; $num1++) $salt .= substr($valori,rand(0,60),1);
+} # fine else if ($md5p)
+} # fine else if (defined('C_ADMIN_SALT'))
+for ($num1 = $md5p ; $num1 < 15 ; $num1++) $passw = md5($passw.substr($salt,0,(20 - $num1)));
+esegui_query("update $tableutenti set password = '$passw', salt = '$salt', tipo_pass = '5' where idutenti = '1'");
+$fileaperto = fopen(C_DATI_PATH."/abilita_login","w+");
+fclose($fileaperto);
+} # fine if (strcmp($passw,""))
+} # fine if (strcmp($admin,""))
+@unlink(C_DATI_PATH."/ini.php");
+} # fine if (C_UTILIZZA_SEMPRE_DEFAULTS == "AUTO" and @is_file(C_DATI_PATH."/ini.php"))
+
 $tablemessaggi = $PHPR_TAB_PRE."messaggi";
 $testo = "<div style=\"max-width: 600px; line-height: 1.1;\">
 <h4>".mex("Benvenuto a HotelDruid!",$pag)."</h4><br>
