@@ -53,7 +53,7 @@ else include("./includes/head.php");
 
 if ($modifica_utenti) {
 $mostra_tabella_iniziale = "NO";
-$tabelle_lock = array("$tableutenti","$tablesessioni");
+$tabelle_lock = array($tableutenti,$tablesessioni);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if (C_RESTRIZIONI_DEMO_ADMIN == "SI") $cond_escludi_admin = " where idutenti != '1'";
 else $cond_escludi_admin = "";
@@ -171,8 +171,8 @@ if ($n_tipo_pass == "5") {
 srand((double) microtime() * 1000000);
 $valori = "=?#@%abcdefghijkmnpqrstuvwxzABCDEFGHJKLMNPQRSTUVWXZ1234567890";
 $salt = substr($valori,rand(0,4),1);
-for ($num1 = 0 ; $num1 < 19 ; $num1++) $salt .= substr($valori,rand(0,60),1);
-for ($num1 = 0 ; $num1 < 15 ; $num1++) $n_pass = md5($n_pass.substr($salt,0,(20 - $num1)));
+for ($num2 = 0 ; $num2 < 19 ; $num2++) $salt .= substr($valori,rand(0,60),1);
+for ($num2 = 0 ; $num2 < 15 ; $num2++) $n_pass = md5($n_pass.substr($salt,0,(20 - $num2)));
 } # fine if ($n_tipo_pass == "5")
 esegui_query("update $tableutenti set password = '$n_pass', salt = '$salt' where idutenti = '$id'");
 if ($id == 1) {
@@ -301,12 +301,12 @@ aggiorna_relutenti("","","","SI",$id_utente,$nuovo_id,"","","","","",1,"","paren
 
 
 if ($modifica_pass) {
-$tabelle_lock = array("$tableutenti");
+$tabelle_lock = array($tableutenti);
 $altre_tab_lock = "";
 $tabelle_lock = lock_tabelle($tabelle_lock,$altre_tab_lock);
 $dati_utente = esegui_query("select * from $tableutenti where idutenti = '".aggslashdb($id_utente_pass)."' ");
 if (numlin_query($dati_utente) != 1) $continua = "NO";
-else $nome_utente = risul_query($dati_utente,0,nome_utente);
+else $nome_utente = risul_query($dati_utente,0,'nome_utente');
 if ($id_utente_pass == 1 and C_RESTRIZIONI_DEMO_ADMIN == "SI") $continua = "NO";
 if ($continua == "SI" and ($prima_pass != $seconda_pass or $prima_pass == "" or $prima_pass != str_replace("&","",$prima_pass))) {
 unset($continua);
@@ -399,7 +399,7 @@ for ($num1 = 0 ; $num1 < $num_lista_gruppi ; $num1++) {
 $id_gruppo = risul_query($lista_gruppi,$num1,'idgruppi');
 if ($gruppi_utente[$id_gruppo] == "SI") { $checked = " checked"; $tag_b = "<b>"; $slash_b = "</b>"; }
 else { $checked = ""; $tag_b = ""; $slash_b = ""; }
-echo "<input type=\"checkbox\" name=\"gruppo$id_gruppo\" value=\"SI\"$checked> $tag_b".$nome_gruppo[$id_gruppo]."$slash_b<br>";
+echo "<label><input type=\"checkbox\" name=\"gruppo$id_gruppo\" value=\"SI\"$checked> $tag_b".$nome_gruppo[$id_gruppo]."$slash_b</label><br>";
 } # fine for $num1
 echo "".mex("Nuovo gruppo",$pag)." <input type=\"text\" name=\"nuovo_gruppo\" size=\"12\"><br><br>
 <input class=\"sbutton\" type=\"submit\" name=\"cont\" value=\"".mex("Modifica",$pag)."\">
