@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -53,8 +53,8 @@ $tablepersonalizza = $PHPR_TAB_PRE."personalizza";
 
 #@include("./includes/costanti.php");
 #@include(C_DATI_PATH."/costanti.php");
-define('C_PHPR_VERSIONE_NUM',2.01);
-define('C_PHPR_VERSIONE_TXT',"2.0.1");
+define('C_PHPR_VERSIONE_NUM',2.02);
+define('C_PHPR_VERSIONE_TXT',"2.0.2");
 
 # Se non si specifica nessun anno uso l'attuale
 $anno_corrente = date("Y",(time() + (C_DIFF_ORE * 3600)));
@@ -70,6 +70,8 @@ if (@is_file(C_DATI_PATH."/selectperiodi$anno_corrente.1.php")) $anno = $anno_co
 } # fine else if ($id_sessione)
 } # fine if (!$anno)
 
+if ($vers_hinc) $vers_hinc = "?v=".C_PHPR_VERSIONE_NUM;
+
 if ($_SERVER['SERVER_NAME']) $HOSTNAME = $_SERVER['SERVER_NAME'];
 elseif ($SERVER_NAME) $HOSTNAME = $SERVER_NAME;
 $HOSTNAME = htmlspecialchars($HOSTNAME);
@@ -579,6 +581,7 @@ $mess = $titolo;
 if ($commento_subordinazione) $mess .= " ($commento_subordinazione)";
 echo "<big><big>$mess:</big></big><br><div style=\"height: 6px\"></div>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$action\"><div>
+<input type=\"hidden\" name=\"vers_hinc\" value=\"1\">
 $input_var_passate
 ".mex("Nome utente","funzioni.php").": <input type=\"text\" name=\"nome_utente_phpr\" size=\"12\"><br>
 ".mex("Password","funzioni.php").": <input type=\"password\" name=\"password_phpr\" size=\"12\" autocorrect=\"off\" autocapitalize=\"off\"><br>
