@@ -28,6 +28,11 @@ $t1cellspacing = "2";
 $t1cellpadding = "3";
 $t2row1color = "#ffffff";
 $t2row2color = "#f7f7f7";
+$t1dates = "#daedff";
+$t1datesout = "#b7dcff";
+$t1seldate = "#ffffff";
+$t1dropin = "#05e105";
+$t1dropout = "#297929";
 
 
 echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
@@ -38,9 +43,9 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 <title> $titolo </title>";
 if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
 echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
-<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css\">
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
 ";
-if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js\">
+if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
 echo "</head>
