@@ -84,6 +84,20 @@ case "Importa ora":				$messaggio = "Import now"; break;
 case "variabili e condizioni del documento":	$messaggio = "variables and conditions from document"; break;
 case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "current variables and coditions will be deleted"; break;
 case "Visualizza le condizioni del documento":	$messaggio = "view conditions of document"; break;
+case "il giorno":  				$messaggio = "the day"; break;
+case "il mese":  				$messaggio = "the month"; break;
+case "l'anno":  				$messaggio = "the year"; break;
+case "il giorno della settimana":  		$messaggio = "the day of the week"; break;
+case "della data":  				$messaggio = "from date"; break;
+case "contiene":  				$messaggio = "contains"; break;
+case "maiusc./minusc.":  			$messaggio = "case sensitive"; break;
+case "la data":  				$messaggio = "the date"; break;
+case "formato ISO":  				$messaggio = "ISO format"; break;
+case "formato corrente":  			$messaggio = "current format"; break;
+case "giorni":  				$messaggio = "days"; break;
+case "mesi":  					$messaggio = "months"; break;
+case "anni":  					$messaggio = "years"; break;
+case "i valori dell'array":  			$messaggio = "the values from array"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
