@@ -241,7 +241,7 @@ case "Le commissioni sono state modificate":  	$messaggio = "Las comisiones han
 case "Le commissioni sono errate":  		$messaggio = "Las comisiones están equivocadas"; break;
 case "Le tasse sono state modificate":  	$messaggio = "Las tasas han sido modificadas"; break;
 case "Le tasse sono errate":  			$messaggio = "Las tasas están equivocadas"; break;
-case "tutti i prezzi delle tariffe si intendono tasse incluse":	$messaggio = "todos los precios de las tarifas se consideran con tasas ya incluidas"; break;
+case "tutti i prezzi delle tariffe si intendono con tasse già incluse":	$messaggio = "todos los precios de las tarifas se consideran con tasas ya incluidas"; break;
 case "Inserisci o modifica le commissioni normali":	$messaggio = "Insertar o modificar las comisiones normales"; break;
 case "Inserisci o modifica le commissioni in questo periodo":	$messaggio = "Insertar o modificar las comisiones en este período"; break;
 case "Sulla":  					$messaggio = "Sobre la"; break;
