@@ -84,6 +84,20 @@ case "Importa ora":				$messaggio = "Importar ahora"; break;
 case "variabili e condizioni del documento":	$messaggio = "variables y condiciones del documento"; break;
 case "le variabili e condizioni attuali verranno cancellate":	$messaggio = "las variables y condiciones actuales serán borradas"; break;
 case "Visualizza le condizioni del documento":	$messaggio = "Ver las condiciones del documento"; break;
+case "il giorno":  				$messaggio = "el día"; break;
+case "il mese":  				$messaggio = "el més"; break;
+case "l'anno":  				$messaggio = "el año"; break;
+case "il giorno della settimana":  		$messaggio = "el día de la semana"; break;
+case "della data":  				$messaggio = "de la fecha"; break;
+case "contiene":  				$messaggio = "contiene"; break;
+case "maiusc./minusc.":  			$messaggio = "maiúsc./minúsc."; break;
+case "la data":  				$messaggio = "la fecha"; break;
+case "formato ISO":  				$messaggio = "formato ISO"; break;
+case "formato corrente":  			$messaggio = "formato actual"; break;
+case "giorni":  				$messaggio = "días"; break;
+case "mesi":  					$messaggio = "meses"; break;
+case "anni":  					$messaggio = "años"; break;
+case "i valori dell'array":  			$messaggio = "los valores del array"; break;
 case "":  		$messaggio = ""; break;
 case "":  		$messaggio = ""; break;
 
