@@ -2,7 +2,7 @@
 
 ##################################################################################
 #    HOTELDRUID
-#    Copyright (C) 2001-2011 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
+#    Copyright (C) 2001-2012 by Marco Maria Francesco De Santis (marco@digitaldruid.net)
 #
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU Affero General Public License as published by
@@ -268,6 +268,22 @@ $num_var_predef_ripeti = $num_var_predef - $num_var_non_ripeti;
 
 
 
+$var_predef_data = "";
+
+$var_predef_data['data_nascita'] = 1;
+$var_predef_data['scadenza_documento'] = 1;
+$var_predef_data['data_inizio'] = 1;
+$var_predef_data['data_fine'] = 1;
+$var_predef_data['data_ultimo_pagamento'] = 1;
+$var_predef_data['data_inserimento_prenotazione'] = 1;
+$var_predef_data['data_nascita_ospite'] = 1;
+$var_predef_data['scadenza_documento_ospite'] = 1;
+$var_predef_data['data_inizio_selezione'] = 1;
+$var_predef_data['data_fine_selezione'] = 1;
+$var_predef_data['oggi'] = 1;
+
+
+
 $var_riserv = "";
 
 $var_riserv['contratto'] = 1;
