@@ -176,7 +176,7 @@ esegui_query("delete from $tablerelinventario where idappartamento = '$idapparta
 esegui_query("delete from $tabledescrizioni where nome = '$idappartamenti' and (tipo = 'appdescr' or tipo = 'appfoto') ");
 $id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
-$fileaperto = fopen("dati/selectappartamenti.php","w+");
+$fileaperto = fopen(C_DATI_PATH."/selectappartamenti.php","w+");
 flock($fileaperto,2);
 fwrite($fileaperto,"<?php \necho \"\n");
 for ( $num = 0; $num < $num_appartamenti; $num = $num + 1) {
@@ -535,7 +535,7 @@ esegui_query("update $tabledescrizioni set nome = '$n_nome_app' where nome = '$i
 $idappartamenti = $n_nome_app;
 $id_appartamenti = esegui_query("select idappartamenti from $tableappartamenti order by idappartamenti ");
 $num_appartamenti = numlin_query($id_appartamenti);
-$fileaperto = fopen("dati/selectappartamenti.php","w+");
+$fileaperto = fopen(C_DATI_PATH."/selectappartamenti.php","w+");
 flock($fileaperto,2);
 fwrite($fileaperto,"<?php \necho \"\n");
 for ( $num = 0; $num < $num_appartamenti; $num = $num + 1) {
