@@ -521,7 +521,7 @@ if ($errore == "SI") break;
 } # fine for $num1
 if ($livello != 0) $errore = "SI";
 $contr_controlla_int = str_replace("[c]","[c\\]",$contr_controlla_int);
-$contr_controlla_int = preg_replace("/\\[c +[A-Za-z]+[A-Za-z0-9_]* *!?= *\"[^\"]*\" *\\]/","[c]",$contr_controlla_int);
+$contr_controlla_int = preg_replace("/\\[c +[A-Za-z]+[A-Za-z0-9_]*(\\((('[^'\\]\\(]*')|([A-Za-z]+[A-Za-z0-9_]*))\\))? *!?= *\"[^\"]*\" *\\]/","[c]",$contr_controlla_int);
 $contr_controlla = explode("[c]",$contr_controlla_int);
 $num_contr_controlla = count($contr_controlla);
 for ($num1 = 1 ; $num1 < $num_contr_controlla ; $num1++) {
@@ -540,7 +540,7 @@ else esegui_query("insert into $tablecontratti (numero,tipo,testo) values ('$num
 } # fine else if (!$multilingua)
 echo "".mex("Documento salvato",$pag).".<br>";
 } # fine else if ($errore == "SI")
-} # fine if (numlin_query($testo_contr))
+} # fine if (numlin_query($vecchio_contr))
 unlock_tabelle($tabelle_lock);
 } # fine if ($salva_modifiche)
 
