@@ -413,7 +413,7 @@ $mostra_form_iniziale = "NO";
 $continua = "SI";
 if ($inizializza != "rpt" and $inizializza != "inr" and $inizializza != "ind") $continua = "NO";
 if (strcmp($cond_sempre,"") and $cond_sempre != "SI" and $cond_sempre != "NO") $continua = "NO";
-if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
+if ($azione != "set" and $azione != "trunc" and $azione != "oper" and $azione != "date" and $azione != "unset" and $azione != "array" and $azione != "break" and $azione != "cont") $continua = "NO";
 if ($num_se < 1 or $num_se > 50) $continua = "NO";
 if ($num_se > 1 and $and_or != "and" and $and_or != "or") $continua = "NO";
 if ($continua == "SI") {
@@ -456,7 +456,7 @@ return $var_txt;
 } # fine function controlla_testo_input
 
 $testo = "$inizializza#@?";
-$tabelle_lock = array("$tablecontratti");
+$tabelle_lock = array($tablecontratti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 if ($num_cond_mod) {
 $cond_esist = @esegui_query("select numero from $tablecontratti where numero = '".aggslashdb($num_cond_mod)."' and tipo = 'cond$contr_cond' ");
@@ -466,9 +466,11 @@ if ($cond_sempre != "SI") {
 if ($num_se > 1) $testo .= $and_or;
 for ($num1 = 1 ; $num1 <= $num_se ; $num1++) {
 controlla_var_se(${"var_se".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
-if (${"cond".$num1} != "=" and ${"cond".$num1} != "!=" and ${"cond".$num1} != "mag" and ${"cond".$num1} != "min") $continua = "NO";
+if (${"cond".$num1} != "=" and ${"cond".$num1} != "!=" and ${"cond".$num1} != "mag" and ${"cond".$num1} != "min" and ${"cond".$num1} != "con" and ${"cond".$num1} != "cmm") $continua = "NO";
 if (${"cond".$num1} == "mag") ${"cond".$num1} = ">";
 if (${"cond".$num1} == "min") ${"cond".$num1} = "<";
+if (${"cond".$num1} == "con") ${"cond".$num1} = "{}";
+if (${"cond".$num1} == "cmm") ${"cond".$num1} = "{A}";
 if (${"tipo_val_se".$num1} != "txt" and ${"tipo_val_se".$num1} != "var") $continua = "NO";
 if (${"tipo_val_se".$num1} == "txt") $val_se = controlla_testo_input(${"val_se_txt".$num1});
 else $val_se = controlla_var_se(${"val_se_sel".$num1},$continua,$var_predef,$num_var_predef,$contr_cond);
@@ -513,6 +515,16 @@ if ($operatore == "/" and !$val_arrotond) $continua = "NO";
 if (strcmp($val_arrotond,"") and !strcmp(str_replace("0","",$val_arrotond),"")) $continua = "NO";
 $testo .= "oper#%?$var_oper#%?$var_oper2#%?$operatore#%?$tipo_val_oper#%?$val_oper#%?$val_arrotond";
 } # fine if ($azione == "oper")
+if ($azione == "date") {
+controlla_var_allora($var_data,$continua,$contr_cond);
+controlla_var_se($var_data2,$continua,$var_predef,$num_var_predef,$contr_cond);
+if ($subdata != "gi" and $subdata != "me" and $subdata != "an" and $subdata != "gs" and $subdata != "is" and $subdata != "da") $continua = "NO";
+if ($oper_giorni != "+" and $oper_giorni != "-") $continua = "NO";
+if (!strcmp($num_giorni,"") or controlla_num_pos($num_giorni) == "NO") $continua = "NO";
+if ($num_giorni and $oper_giorni == "-") $num_giorni = ($num_giorni * -1);
+if ($tipo_giorni != "g" and $tipo_giorni != "m" and $tipo_giorni != "a") $continua = "NO";
+$testo .= "date#%?$var_data#%?$var_data2#%?$subdata#%?$num_giorni#%?$tipo_giorni";
+} # fine if ($azione == "date")
 if ($azione == "unset") {
 if (substr($arr_azz,0,1) != "a") $continua = "NO";
 controlla_var_allora($arr_azz,$continua,$contr_cond);
@@ -528,9 +540,15 @@ $var_arr_pers = $arr_pers_vett[1];
 $var_non_predef = esegui_query("select numero from $tablecontratti where (tipo = 'var' or tipo = 'var$contr_cond') and testo = '".aggslashdb($var_arr_pers)."' ");
 if (!numlin_query($var_non_predef)) $continua = "NO";
 } # fine if (numlin_query($arr_esistente) != 1)
-if ($tipo_arr != "dat" and $tipo_arr != "val") $continua = "NO";
+if ($tipo_arr != "dat" and $tipo_arr != "val" and $tipo_arr != "cop") $continua = "NO";
+$lista_val = "";
 if ($tipo_arr == "val") $lista_val = controlla_testo_input($lista_val);
-else $lista_val = "";
+if ($tipo_arr == "cop") {
+$lista_val = $array2;
+if (substr($array2,0,1) != "a") $continua = "NO";
+$arr_esistente = esegui_query("select * from $tablecontratti where (tipo = 'vett' or tipo = 'vett$contr_cond') and numero = '".aggslashdb(substr($array2,1))."'");
+if (numlin_query($arr_esistente) != 1) $continua = "NO";
+} # fine if ($tipo_arr == "cop")
 $testo .= "array#%?$array#%?$tipo_arr#%?$lista_val";
 } # fine if ($azione == "array")
 if ($azione == "break") {
@@ -651,6 +669,7 @@ $num_variabili_pers = numlin_query($variabili_pers);
 $option_var_pers = "";
 $nome_var['-1'] = mex2('messaggio_di_errore');
 $nome_var['-2'] = mex2('errore_ripetizione');
+$num_var_predef_orig = $num_var_predef;
 for ($num1 = 0 ; $num1 < $num_variabili_pers ; $num1++) {
 $var_pers = risul_query($variabili_pers,$num1,'testo');
 $num_var_pers = risul_query($variabili_pers,$num1,'numero');
@@ -678,7 +697,7 @@ $option_var_pers
 } # fine if ($option_var_pers)
 echo "&nbsp;&nbsp;&nbsp;<input name=\"nuova_var_pers\" size=\"20\" maxlength=\"50\" type=\"text\">
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_var_pers\" value=\"".mex("Aggiungi",$pag)."\">";
-if ($contr_cond and !$contr_importa_vc) echo " (<input type=\"checkbox\" name=\"solo_contr_cond\" value=\"SI\" checked> ".mex("solo al documento",$pag)." $contr_cond)";
+if ($contr_cond and !$contr_importa_vc) echo " (<label><input type=\"checkbox\" name=\"solo_contr_cond\" value=\"SI\" checked> ".mex("solo al documento",$pag)." $contr_cond</label>)";
 echo "</div></form><br>";
 
 
@@ -714,7 +733,7 @@ $option_arr_pers
 } # fine if ($option_arr_pers)
 echo "&nbsp;&nbsp;&nbsp;<input name=\"nuovo_arr_pers\" size=\"20\" maxlength=\"50\" type=\"text\">
 <input class=\"sbutton\" type=\"submit\" name=\"aggiungi_arr_pers\" value=\"".mex("Aggiungi",$pag)."\">";
-if ($contr_cond and !$contr_importa_vc) echo " (<input type=\"checkbox\" name=\"solo_contr_cond\" value=\"SI\" checked> ".mex("solo al documento",$pag)." $contr_cond)";
+if ($contr_cond and !$contr_importa_vc) echo " (<label><input type=\"checkbox\" name=\"solo_contr_cond\" value=\"SI\" checked> ".mex("solo al documento",$pag)." $contr_cond</label>)";
 echo "</div></form><br>";
 
 
@@ -824,6 +843,8 @@ if ($se_cond_corr[1] == "=") $str_cond .= mex("è uguale a",$pag);
 if ($se_cond_corr[1] == "!=") $str_cond .= mex("è diverso da",$pag);
 if ($se_cond_corr[1] == ">") $str_cond .= mex("è maggiore di",$pag);
 if ($se_cond_corr[1] == "<") $str_cond .= mex("è minore di",$pag);
+if ($se_cond_corr[1] == "{}") $str_cond .= mex("contiene",$pag);
+if ($se_cond_corr[1] == "{A}") $str_cond .= mex("contiene",$pag)." (".mex("maiusc./minusc.",$pag).")";
 if ($se_cond_corr[2] == "var") $str_cond .= " [".mex2($se_cond_corr[3])."] ";
 else $str_cond .= " \"".htmlspecialchars($se_cond_corr[3])."\" ";
 if ($num_cond_mod == $num_cond) {
@@ -831,6 +852,8 @@ ${"var_se".$num2} = $se_cond_corr[0];
 ${"cond".$num2} = $se_cond_corr[1];
 if (${"cond".$num2} == ">") ${"cond".$num2} = "mag";
 if (${"cond".$num2} == "<") ${"cond".$num2} = "min";
+if (${"cond".$num2} == "{}") ${"cond".$num2} = "con";
+if (${"cond".$num2} == "{A}") ${"cond".$num2} = "cmm";
 ${"tipo_val_se".$num2} = $se_cond_corr[2];
 if ($se_cond_corr[2] == "var") ${"val_se_sel".$num2} = $se_cond_corr[3];
 else ${"val_se_txt".$num2} = htmlspecialchars($se_cond_corr[3]);
@@ -903,6 +926,36 @@ $val_arrotond = $azione[6];
 } # fine if ($num_cond_mod == $num_cond)
 } # fine if ($azione[0] == "oper")
 
+if ($azione[0] == "date") {
+$str_cond .= mex("porre",$pag)." [".$nome_var[$azione[1]]."] ".mex("uguale a",$pag)." \"";
+if ($azione[3] == "gi") $str_cond .= mex("il giorno",$pag);
+if ($azione[3] == "me") $str_cond .= mex("il mese",$pag);
+if ($azione[3] == "an") $str_cond .= mex("l'anno",$pag);
+if ($azione[3] == "gs") $str_cond .= mex("il giorno della settimana",$pag);
+if ($azione[3] == "is") $str_cond .= mex("la data",$pag)." (".mex("formato ISO",$pag).")";
+if ($azione[3] == "da") $str_cond .= mex("la data",$pag)." (".mex("formato corrente",$pag).")";
+$str_cond .= "\" ".mex("della data",$pag)." [".mex2($azione[2])."]";
+if ($azione[4]) {
+if ($azione[4] < 0) $str_cond .= " - ".($azione[4] * -1)." ";
+else $str_cond .= " + ".$azione[4]." ";
+if ($azione[5] == "g") $str_cond .= mex("giorni",$pag);
+if ($azione[5] == "m") $str_cond .= mex("mesi",$pag);
+if ($azione[5] == "a") $str_cond .= mex("anni",$pag);
+} # fine if ($azione[4])
+if ($num_cond_mod == $num_cond) {
+$var_data = $azione[1];
+$var_data2 = $azione[2];
+$subdata = $azione[3];
+$num_giorni = $azione[4];
+if ($num_giorni < 0) {
+$num_giorni = ($num_giorni * -1);
+$oper_giorni = "-";
+} # fine if ($num_giorni < 0)
+else $oper_giorni = "+";
+$tipo_giorni = $azione[5];
+} # fine if ($num_cond_mod == $num_cond)
+} # fine if ($azione[0] == "date")
+
 if ($azione[0] == "unset") {
 $str_cond .= mex("azzera l'array",$pag)." [".$nome_var[$azione[1]]."]";
 if ($num_cond_mod == $num_cond) $arr_azz = $azione[1];
@@ -911,11 +964,13 @@ if ($num_cond_mod == $num_cond) $arr_azz = $azione[1];
 if ($azione[0] == "array") {
 $str_cond .= mex("assegna all'array",$pag)." [".$nome_var[$azione[1]]."] ";
 if ($azione[2] == "dat") $str_cond .= mex("valori progressivi tra le date selezionate",$pag);
-else $str_cond .= mex("i valori",$pag)." \"".htmlspecialchars(str_replace(",",", ",$azione[3]))."\"";
+if ($azione[2] == "val") $str_cond .= mex("i valori",$pag)." \"".htmlspecialchars(str_replace(",",", ",$azione[3]))."\"";
+if ($azione[2] == "cop") $str_cond .= mex("i valori dell'array",$pag)." [".$nome_var[$azione[3]]."]";
 if ($num_cond_mod == $num_cond) {
 $array = $azione[1];
 $tipo_arr = $azione[2];
 if ($azione[2] == "val") $lista_val = htmlspecialchars($azione[3]);
+if ($azione[2] == "cop") $array2 = $azione[3];
 } # fine if ($num_cond_mod == $num_cond)
 } # fine if ($azione[0] == "array")
 
@@ -1051,8 +1106,10 @@ $option_var_pers .= "<option value=\"-2\">".mex2('errore_ripetizione')."</option
 
 
 $option_var_predef = "";
+$option_var_predef_data = "";
 for ($num1 = 0 ; $num1 < $num_var_predef ; $num1++) {
 $option_var_predef .= "<option value=\"".$var_predef[$num1]."\">".mex2($var_predef[$num1])."</option>";
+if ($var_predef_data[$var_predef[$num1]] or $num1 >= $num_var_predef_orig) $option_var_predef_data .= "<option value=\"".$var_predef[$num1]."\">".mex2($var_predef[$num1])."</option>";
 } # fine for $num1
 
 
@@ -1064,7 +1121,8 @@ $sel_inidoc = "";
 if (!$inizializza or $inizializza == "rpt") $sel_rip = " selected";
 if ($inizializza == "inr") $sel_inirip = " selected";
 if ($inizializza == "ind") $sel_inidoc = " selected";
-echo "<a name=\"modcond\"></a>
+echo "<div class=\"rbox\" style=\"padding-top: 8px;\">
+<a name=\"modcond\"></a>
 <form accept-charset=\"utf-8\" method=\"post\" action=\"$pag#modcond\"><div>
 <input type=\"hidden\" name=\"anno\" value=\"$anno\">
 <input type=\"hidden\" name=\"id_sessione\" value=\"$id_sessione\">
@@ -1133,6 +1191,8 @@ if (${"cond".$num1} == "=") $sel_ug = " selected";
 if (${"cond".$num1} == "!=") $sel_div = " selected";
 if (${"cond".$num1} == "mag") $sel_mag = " selected";
 if (${"cond".$num1} == "min") $sel_min = " selected";
+if (${"cond".$num1} == "con") $sel_con = " selected";
+if (${"cond".$num1} == "cmm") $sel_cmm = " selected";
 echo "<td>$fr_se</td><td><select name=\"var_se$num1\">
 ".str_replace("\"".${"var_se".$num1}."\">","\"".${"var_se".$num1}."\" selected>",$option_var_predef)."
 </select></td><td><select name=\"cond$num1\">
@@ -1140,6 +1200,8 @@ echo "<td>$fr_se</td><td><select name=\"var_se$num1\">
 <option value=\"!=\"$sel_div>".mex("è diverso da",$pag)."</option>
 <option value=\"mag\"$sel_mag>".mex("è maggiore di",$pag)."</option>
 <option value=\"min\"$sel_min>".mex("è minore di",$pag)."</option>
+<option value=\"con\"$sel_con>".mex("contiene",$pag)."</option>
+<option value=\"cmm\"$sel_cmm>".mex("contiene",$pag)." (".mex("maiusc./minusc.",$pag).")</option>
 </select></td><td><b style=\"font-size: 260%;\">{</b></td><td>
 <table cellspacing=\"0\"><tr><td>
 <input type=\"radio\" id=\"val_se_txt$num1\" name=\"tipo_val_se$num1\" value=\"txt\"$chk_txt></td><td>
@@ -1265,6 +1327,60 @@ echo "<table><tr onclick=\"document.getElementById('az_oper').checked='1'\"><td>
 (".mex("Utilizzare una variabile personalizzata che finisce con \"_p\" per aggiungervi i separatori delle migliaia dopo l'operazione",$pag).")
 </small></td></tr></table><br>";
 
+if ($azione == "date") $chk_az = " checked";
+else $chk_az = "";
+$sel_gi = "";
+$sel_me = "";
+$sel_an = "";
+$sel_gs = "";
+$sel_is = "";
+$sel_co = "";
+if ($subdata == "gi") $sel_gi = " selected";
+if ($subdata == "me") $sel_me = " selected";
+if ($subdata == "an") $sel_an = " selected";
+if ($subdata == "gs") $sel_gs = " selected";
+if ($subdata == "is") $sel_is = " selected";
+if ($subdata == "da") $sel_da = " selected";
+$sel_piu = "";
+$sel_men = "";
+if ($oper_giorni == "+") $sel_piu = " selected";
+if ($oper_giorni == "-") $sel_men = " selected";
+if (!strcmp($num_giorni,"")) $num_giorni = "0";
+$sel_g = "";
+$sel_m = "";
+$sel_a = "";
+if ($tipo_giorni == "g") $sel_g = " selected";
+if ($tipo_giorni == "m") $sel_m = " selected";
+if ($tipo_giorni == "a") $sel_a = " selected";
+echo "<table><tr onclick=\"document.getElementById('az_date').checked='1'\"><td>
+<input type=\"radio\" id=\"az_date\" name=\"azione\" value=\"date\"$chk_az>
+</td><td>".ucfirst(mex("porre",$pag))." </td><td><select name=\"var_data\">
+".str_replace("\"$var_data\">","\"$var_data\" selected>",$option_var_pers)."
+</select></td><td>".str_replace(" ","&nbsp;",mex("uguale a",$pag))."</td><td>
+<select name=\"subdata\">
+<option value=\"gi\"$sel_gi>".mex("il giorno",$pag)."</option>
+<option value=\"me\"$sel_me>".mex("il mese",$pag)."</option>
+<option value=\"an\"$sel_an>".mex("l'anno",$pag)."</option>
+<option value=\"gs\"$sel_gs>".mex("il giorno della settimana",$pag)."</option>
+<option value=\"is\"$sel_is>".mex("la data",$pag)." (".mex("formato ISO",$pag).")</option>
+<option value=\"da\"$sel_da>".mex("la data",$pag)." (".mex("formato corrente",$pag).")</option>
+</select></td><td>
+".str_replace(" ","&nbsp;",mex("della data",$pag))."</td><td>
+<select name=\"var_data2\">
+".str_replace("\"$var_data2\">","\"$var_data2\" selected>",$option_var_predef_data)."
+</select></td><td>
+<select name=\"oper_giorni\">
+<option value=\"+\"$sel_piu>+</option>
+<option value=\"-\"$sel_men>-</option>
+</select></td><td>
+<input type=\"text\" name=\"num_giorni\" value=\"$num_giorni\" size=\"3\" maxlength=\"150\">
+</td><td>
+<select name=\"tipo_giorni\">
+<option value=\"g\"$sel_g>".mex("giorni",$pag)."</option>
+<option value=\"m\"$sel_m>".mex("mesi",$pag)."</option>
+<option value=\"a\"$sel_a>".mex("anni",$pag)."</option>
+</select></td></tr></table><br>";
+
 if ($option_arr_pers) {
 if ($azione == "unset") $chk_az = " checked";
 else $chk_az = "";
@@ -1279,8 +1395,12 @@ echo "<table onclick=\"document.getElementById('az_azzera').checked='1'\"><tr><t
 if ($opt_arr_var_non_predef) {
 if ($azione == "array") $chk_az = " checked";
 else $chk_az = "";
-if ($tipo_arr == "val") { $chk_val = " checked"; $chk_dat = ""; }
-else { $chk_val = ""; $chk_dat = " checked"; }
+$chk_dat = "";
+$chk_val = "";
+$chk_cop = "";
+if ($tipo_arr == "dat" or !$tipo_arr) $chk_dat = " checked";
+if ($tipo_arr == "val") $chk_val = " checked";
+if ($tipo_arr == "cop") $chk_cop = " checked";
 echo "<table onclick=\"document.getElementById('az_array').checked='1'\"><tr><td>
 <input type=\"radio\" id=\"az_array\" name=\"azione\" value=\"array\"$chk_az>
 </td><td>".str_replace(" ","&nbsp;",ucfirst(mex("assegna all'array",$pag)))."</td><td>
@@ -1297,7 +1417,14 @@ echo "<table onclick=\"document.getElementById('az_array').checked='1'\"><tr><td
 ".str_replace(" ","&nbsp;",mex("una lista di valori predefiniti",$pag)).":</td>
 <td><input type=\"text\" name=\"lista_val\" value=\"$lista_val\" size=\"26\"></td>
 <td>(".str_replace(" ","&nbsp;",mex("separati da virgole",$pag)).").
-</td></tr></table></td></tr></table>
+</td></tr></table></td></tr>
+<tr onclick=\"document.getElementById('arr_cop').checked='1'\"><td>
+<input type=\"radio\" id=\"arr_cop\" name=\"tipo_arr\" value=\"cop\"$chk_cop></td><td>
+<table cellspacing=\"0\"><tr><td>
+".str_replace(" ","&nbsp;",mex("i valori dell'array",$pag)." ")."</td>
+<td><select name=\"array2\">
+".str_replace("\"$array2\">","\"$array2\" selected>",$option_arr_pers)."
+</select>.</td></tr></table></td></tr></table>
 </td></tr></table><br>";
 } # fine if ($opt_arr_var_non_predef)
 
@@ -1335,7 +1462,7 @@ $input_cond_contr
 <input class=\"sbutton\" type=\"submit\" value=\"".ucfirst(mex("annulla",$pag))."\">
 </div></div></form><br>";
 } # fine if ($num_cond_mod)
-echo "<br>";
+echo "</div><br>";
 
 } # fine if ($option_var_pers and !$contr_importa_vc)
 
