@@ -30,6 +30,11 @@ $t1cellspacing = "0";
 $t1cellpadding = "3";
 $t2row1color = "#ffffff";
 $t2row2color = "#f7f7f7";
+$t1dates = "#daedff";
+$t1datesout = "#b7dcff";
+$t1seldate = "#ffffff";
+$t1dropin = "#05e105";
+$t1dropout = "#297929";
 #$start_time = microtime();
 
 
@@ -46,16 +51,16 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
 if (C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css\" media=\"all\">
-<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/stylesheet.css\" media=\"all\">
+echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\" media=\"all\">
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/stylesheet.css$vers_hinc\" media=\"all\">
 ";
-if (!$mobile_device) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/screen.css\" media=\"screen\">
+if (!$mobile_device) echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/screen.css$vers_hinc\" media=\"screen\">
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/paper.css\" media=\"print\">
-<script type=\"text/javascript\" src=\"./themes/$tema_corr/inc/functions.js\">
+echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/$tema_corr/inc/paper.css$vers_hinc\" media=\"print\">
+<script type=\"text/javascript\" src=\"./themes/$tema_corr/inc/functions.js$vers_hinc\">
 </script>
 ";
-if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js\">
+if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
 if ($show_bar == "NO") echo "<style type=\"text/css\">
