@@ -30,6 +30,11 @@ $t1cellspacing = "0";
 $t1cellpadding = "3";
 $t2row1color = "#ffffff";
 $t2row2color = "#f7f7f7";
+$t1dates = "#daedff";
+$t1datesout = "#b7dcff";
+$t1seldate = "#ffffff";
+$t1dropin = "#05e105";
+$t1dropout = "#297929";
 
 
 # head
@@ -44,11 +49,11 @@ echo "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"
 if ($pag == "visualizza_contratto.php" and $extra_head) echo $extra_head;
 if (C_NASCONDI_MARCA != "SI") echo "<link rel=\"shortcut icon\" type=\"image/x-icon\" href=\"./img/favicon.ico\">
 ";
-if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js\">
+if ($base_js) echo "<script type=\"text/javascript\" src=\"./base.js$vers_hinc\">
 </script>
 ";
-echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css\">
-<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/snj/inc/stylesheet.css\" media=\"all\">
+echo "<link rel=\"stylesheet\" type=\"text/css\" href=\"./base.css$vers_hinc\">
+<link rel=\"stylesheet\" type=\"text/css\" href=\"./themes/snj/inc/stylesheet.css$vers_hinc\" media=\"all\">
 </head>
 <body";
 if ($drag_drop) echo " ondragover=\"event.preventDefault();\" ondragenter=\"event.preventDefault();\" ondrop=\"event.preventDefault();drp_out();\"";
