@@ -198,7 +198,9 @@ else include("./includes/head.php");
 if ($modifica_pers == "NO") {
 $mittente_email = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'dati_struttura' and idutente = '$id_utente'");
 $mittente_email = explode("#@&",risul_query($mittente_email,0,'valpersonalizza'));
+$nome_mittente_email = $mittente_email[5];
 $mittente_email = $mittente_email[2];
+if ($nome_mittente_email) $mittente_email = "$nome_mittente_email <$mittente_email>";
 } # fine if ($modifica_pers == "NO")
 $maschera_envelope = esegui_query("select * from $tablepersonalizza where idpersonalizza = 'maschera_email' and idutente = '1'");
 $maschera_envelope = risul_query($maschera_envelope,0,'valpersonalizza');
@@ -234,7 +236,13 @@ case "WIN": $mailh_nl = "\r\n"; break;
 case "MAC": $mailh_nl = "\r"; break;
 default: $mailh_nl = "\n"; break;
 } # fine switch (strtoupper(substr(PHP_OS,0,3)))
-$headers = "From: <$mittente_email>$mailh_nl";
+if (strstr($mittente_email,"<")) {
+$headers = "From: $mittente_email$mailh_nl";
+$mittente_email = explode("<",$mittente_email);
+$mittente_email = explode(">",$mittente_email[1]);
+$mittente_email = $mittente_email[0];
+} # fine if (strstr($mittente_email,"<"))
+else $headers = "From: <$mittente_email>$mailh_nl";
 if ($bcc_mittente == "SI") $headers .= "Bcc: $mittente_email$mailh_nl";
 if ($bcc_indirizzo) $headers .= "Bcc: $bcc_indirizzo$mailh_nl";
 $testo_email = chunk_split(base64_encode(${"testo_email".$num1}));
@@ -282,7 +290,7 @@ if ($bcc_indirizzo) echo $bcc_indirizzo;
 if ($bcc_mittente == "SI" or $bcc_indirizzo) echo ")";
 echo ".<br>";
 # inserisco il soggetto di questa email come inviato per i clienti corrispondenti
-$tabelle_lock = array("$tableclienti");
+$tabelle_lock = array($tableclienti);
 $tabelle_lock = lock_tabelle($tabelle_lock);
 $destinatari_email = explode(",",$destinatario_email);
 for ($num2 = 0 ; $num2 < count($destinatari_email) ; $num2++) {
